@@ -19,7 +19,7 @@ use YAML::Any         qw/Dump/;
 use namespace::clean -except => 'meta';
 
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 has 'config'      => (is => 'bare', isa => 'HashRef', required => 1);
 has 'dir'         => (is => 'ro',   isa => 'Str',
@@ -65,7 +65,7 @@ sub _datasources {
   my $source_class   = $self->find_class('DataSource');
   my $config_sources = $self->config('datasources');
   return {map {($_ => $source_class->new(name => $_, app => $self))}
-              keys %$config_sources};
+              sort keys %$config_sources};
 }
 
 sub _share_paths {
@@ -871,17 +871,11 @@ L<http://www.codeplex.com/ChinookDatabase>.
 
 =head1 TODO
 
-
-
- - check multiple updates on CLE_PROC (space OK ?)
-
  - column properties
     - noinsert, noupdate, nosearch, etc.
 
  - edit: select or autocompleter for foreign keys
 
- - descr: highlight primary key
-
  - internationalisation
     - 
 
@@ -897,10 +891,6 @@ L<http://www.codeplex.com/ChinookDatabase>.
 
   - quoting problem (FromQuery: "J&B")
 
-  - app-specific exception handling instead of Plack error messages
-
-  - datasources in homepage should be ordered
-
   - readonly fields: tabindex -1 (can be done by CSS?)
     in fact, current values should NOT be input fields, but plain SPANs
 
@@ -908,19 +898,10 @@ L<http://www.codeplex.com/ChinookDatabase>.
   - Update form, focus problem (focus in field should deactivate TreeNav)
   - add insert link in table descr
 
-  - export Excel : use column groups
-  - export Excel : figer les volets
-
   - deal with Favicon.ico
 
   - declare in http://www.sqlite.org/cvstrac/wiki?p=ManagementTools
 
-  - bulk update : should display the "update" SQL
-  - bulk update : bad alignment in form ('where' / 'and')
-  - bulk update : maybe would need special authorization
-
-  - add a .tsv View
-
   - multicolumns : if there is an association over a multicolumns key,
      it is not displayed as a hyperlink in /list. To do so, we would need
      to add a line in the display, corresponding to the multicolumn.
